==> jc-1.4.0.tar.gz: java/awt/geom/Arc2D__24ArcIterator.h <==
// final class java.awt.geom.Arc2D$ArcIterator

// class file dependencies
// @dep_class 51253745bc444997 java_awt_geom_Arc2D__24ArcIterator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Arc2D__24ArcIterator_H_
#define _JC_java_awt_geom_Arc2D__24ArcIterator_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_Arc2D$object;
struct _jc_java_awt_geom_Ellipse2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$sub_refs	_jc_java_awt_geom_Arc2D__24ArcIterator$sub_refs;
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$sub_nonrefs	_jc_java_awt_geom_Arc2D__24ArcIterator$sub_nonrefs;
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$refs	_jc_java_awt_geom_Arc2D__24ArcIterator$refs;
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$nonrefs	_jc_java_awt_geom_Arc2D__24ArcIterator$nonrefs;
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$object	_jc_java_awt_geom_Arc2D__24ArcIterator$object;

typedef const struct _jc_java_awt_geom_Arc2D__24ArcIterator$vmethods	_jc_java_awt_geom_Arc2D__24ArcIterator$vmethods;
typedef const struct _jc_java_awt_geom_Arc2D__24ArcIterator$vtable	_jc_java_awt_geom_Arc2D__24ArcIterator$vtable;
typedef const struct _jc_java_awt_geom_Arc2D__24ArcIterator$vtype	_jc_java_awt_geom_Arc2D__24ArcIterator$vtype;

// Constructors
extern void _jc_java_awt_geom_Arc2D__24ArcIterator$method$_init$a0f2894846d675bc(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_java_awt_geom_Arc2D$object *, struct _jc_java_awt_geom_AffineTransform$object *);
extern void _jc_java_awt_geom_Arc2D__24ArcIterator$method$_init$fbe0fbf68ffb6ba3(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_java_awt_geom_Ellipse2D$object *, struct _jc_java_awt_geom_AffineTransform$object *);

// Virtual methods
extern jint _jc_java_awt_geom_Arc2D__24ArcIterator$method$currentSegment$6f11896d92c6b52a(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_double_array *);
extern jint _jc_java_awt_geom_Arc2D__24ArcIterator$method$currentSegment$cecac40191e782ca(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_float_array *);
extern jint _jc_java_awt_geom_Arc2D__24ArcIterator$method$getWindingRule$91001ac946a586fb(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *);
extern jboolean _jc_java_awt_geom_Arc2D__24ArcIterator$method$isDone$5a7c3805879a074d(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *);
extern void _jc_java_awt_geom_Arc2D__24ArcIterator$method$next$08839245f4046cfe(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$currentSegment$6f11896d92c6b52a;
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$currentSegment$cecac40191e782ca;
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$getWindingRule$91001ac946a586fb;
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$isDone$5a7c3805879a074d;
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$next$08839245f4046cfe;

// Virtual methods structure
struct _jc_java_awt_geom_Arc2D__24ArcIterator$vmethods {
	jint	(*currentSegment$6f11896d92c6b52a)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_double_array *);
	jint	(*currentSegment$cecac40191e782ca)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_float_array *);
	jint	(*getWindingRule$91001ac946a586fb)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *);
	jboolean	(*isDone$5a7c3805879a074d)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *);
	void	(*next$08839245f4046cfe)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *);
};

// Vtable
struct _jc_java_awt_geom_Arc2D__24ArcIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Arc2D__24ArcIterator$vmethods	java_awt_geom_Arc2D__24ArcIterator;
};

// Vtype
struct _jc_java_awt_geom_Arc2D__24ArcIterator$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Arc2D__24ArcIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Arc2D__24ArcIterator$sub_refs {
	struct _jc_java_awt_geom_AffineTransform$object	*xform;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Arc2D__24ArcIterator$refs {
    _jc_java_awt_geom_Arc2D__24ArcIterator$sub_refs	java_awt_geom_Arc2D__24ArcIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Arc2D__24ArcIterator$sub_nonrefs {
	jint	current;
	jint	limit;
	jdouble	x;
	jdouble	y;
	jdouble	w;
	jdouble	h;
	jdouble	start;
	jdouble	extent;
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Arc2D__24ArcIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Arc2D__24ArcIterator$sub_nonrefs	java_awt_geom_Arc2D__24ArcIterator;
};

// Object instance structure
struct _jc_java_awt_geom_Arc2D__24ArcIterator$object {
	_jc_java_awt_geom_Arc2D__24ArcIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Arc2D__24ArcIterator$vtype	*vtype;
	_jc_java_awt_geom_Arc2D__24ArcIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Arc2D__24ArcIterator$vtype _jc_java_awt_geom_Arc2D__24ArcIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Arc2D__24ArcIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Arc2D__24ArcIterator$class_object;

#endif	/* _JC_java_awt_geom_Arc2D__24ArcIterator_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Arc2D__24ArcIterator.h <==
// final class java.awt.geom.Arc2D$ArcIterator

// class file dependencies
// @dep_class 72367a9946f7fb9e java_awt_geom_Arc2D__24ArcIterator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_geom_Arc2D__24ArcIterator_H_
#define _JC_java_awt_geom_Arc2D__24ArcIterator_H_

// Forward structure declarations
struct _jc_java_awt_geom_AffineTransform$object;
struct _jc_java_awt_geom_Arc2D$object;
struct _jc_java_awt_geom_Ellipse2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$sub_refs	_jc_java_awt_geom_Arc2D__24ArcIterator$sub_refs;
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$sub_nonrefs	_jc_java_awt_geom_Arc2D__24ArcIterator$sub_nonrefs;
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$refs	_jc_java_awt_geom_Arc2D__24ArcIterator$refs;
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$nonrefs	_jc_java_awt_geom_Arc2D__24ArcIterator$nonrefs;
typedef struct _jc_java_awt_geom_Arc2D__24ArcIterator$object	_jc_java_awt_geom_Arc2D__24ArcIterator$object;

typedef const struct _jc_java_awt_geom_Arc2D__24ArcIterator$vmethods	_jc_java_awt_geom_Arc2D__24ArcIterator$vmethods;
typedef const struct _jc_java_awt_geom_Arc2D__24ArcIterator$vtable	_jc_java_awt_geom_Arc2D__24ArcIterator$vtable;
typedef const struct _jc_java_awt_geom_Arc2D__24ArcIterator$vtype	_jc_java_awt_geom_Arc2D__24ArcIterator$vtype;

// Constructors
extern void _jc_java_awt_geom_Arc2D__24ArcIterator$method$_init$a0f2894846d675bc(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_java_awt_geom_Arc2D$object *, struct _jc_java_awt_geom_AffineTransform$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Arc2D__24ArcIterator$method$_init$fbe0fbf68ffb6ba3(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_java_awt_geom_Ellipse2D$object *, struct _jc_java_awt_geom_AffineTransform$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_geom_Arc2D__24ArcIterator$method$currentSegment$6f11896d92c6b52a(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_double_array *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_geom_Arc2D__24ArcIterator$method$currentSegment$cecac40191e782ca(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_geom_Arc2D__24ArcIterator$method$getWindingRule$91001ac946a586fb(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_geom_Arc2D__24ArcIterator$method$isDone$5a7c3805879a074d(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Arc2D__24ArcIterator$method$next$08839245f4046cfe(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$currentSegment$6f11896d92c6b52a;
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$currentSegment$cecac40191e782ca;
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$getWindingRule$91001ac946a586fb;
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$isDone$5a7c3805879a074d;
extern _jc_method _jc_java_awt_geom_Arc2D__24ArcIterator$method_info$next$08839245f4046cfe;

// Virtual methods structure
struct _jc_java_awt_geom_Arc2D__24ArcIterator$vmethods {
	jint	(*currentSegment$6f11896d92c6b52a)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_double_array *) _JC_JCNI_ATTR;
	jint	(*currentSegment$cecac40191e782ca)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	jint	(*getWindingRule$91001ac946a586fb)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *) _JC_JCNI_ATTR;
	jboolean	(*isDone$5a7c3805879a074d)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *) _JC_JCNI_ATTR;
	void	(*next$08839245f4046cfe)(_jc_env *, struct _jc_java_awt_geom_Arc2D__24ArcIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_Arc2D__24ArcIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Arc2D__24ArcIterator$vmethods	java_awt_geom_Arc2D__24ArcIterator;
};

// Vtype
struct _jc_java_awt_geom_Arc2D__24ArcIterator$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Arc2D__24ArcIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Arc2D__24ArcIterator$sub_refs {
	struct _jc_java_awt_geom_AffineTransform$object	*xform;
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Arc2D__24ArcIterator$refs {
    _jc_java_awt_geom_Arc2D__24ArcIterator$sub_refs	java_awt_geom_Arc2D__24ArcIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Arc2D__24ArcIterator$sub_nonrefs {
	jint	current;
	jint	limit;
	jdouble	x;
	jdouble	y;
	jdouble	w;
	jdouble	h;
	jdouble	start;
	jdouble	extent;
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Arc2D__24ArcIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Arc2D__24ArcIterator$sub_nonrefs	java_awt_geom_Arc2D__24ArcIterator;
};

// Object instance structure
struct _jc_java_awt_geom_Arc2D__24ArcIterator$object {
	_jc_java_awt_geom_Arc2D__24ArcIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Arc2D__24ArcIterator$vtype	*vtype;
	_jc_java_awt_geom_Arc2D__24ArcIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Arc2D__24ArcIterator$vtype _jc_java_awt_geom_Arc2D__24ArcIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Arc2D__24ArcIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Arc2D__24ArcIterator$class_object;

#endif	/* _JC_java_awt_geom_Arc2D__24ArcIterator_H_ */
